@@ -18,7 +18,6 @@ class ProtectionRule(Ppdm):
             self.failure = False
             self.fail_msg = ""
             self.fail_response = {}
-            self.fail_body = {}
             self.name = kwargs['name']
             self.body = {}
             self.target_body = {}
@@ -105,7 +104,6 @@ class ProtectionRule(Ppdm):
                 self.failure = True
                 self.fail_msg = return_body.msg
                 self.fail_response = return_body.response
-                self.fail_body = (self.body.copy()).update(self.target_body)
         self.target_body = {}
         self.get_rule()
 
@@ -184,7 +182,8 @@ class ProtectionRule(Ppdm):
     def __update_protection_rule(self):
         protectionrule_logger.debug("Method: update_protection_rule")
         return_body = helpers.ReturnBody()
-        future_body = self.body.update(self.target_body)
+        future_body = self.body.copy()
+        future_body.update(self.target_body)
         response = super()._rest_put("/protection-rules"
                                      f"/{self.id}", future_body)
         if response.ok:
@@ -206,11 +205,12 @@ class ProtectionRule(Ppdm):
         if response.ok:
             msg = f"Protection Rule id \"{self.name}\" successfully deleted"
             return_body.success = True
+            return_body.response = {}
         else:
             msg = f"Protection Rule id \"{self.name}\" not deleted"
             return_body.success = False
+            return_body.response = response.json()
         protectionrule_logger.debug(msg)
         return_body.msg = msg
-        return_body.response = response.json()
         return_body.status_code = response.status_code
         return return_body
